==> material-ui-shell-1.0.8.tgz: package/es/components/MenuHeader/MenuHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext } from 'react';
import Avatar from '@material-ui/core/Avatar';
import ChevronLeft from '@material-ui/icons/ChevronLeft';
import ChevronRight from '@material-ui/icons/ChevronRight';
import ChromeReaderMode from '@material-ui/icons/ChromeReaderMode';
import IconButton from '@material-ui/core/IconButton';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemAvatar from '@material-ui/core/ListItemAvatar';
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
import ListItemText from '@material-ui/core/ListItemText';
import Paper from '@material-ui/core/Paper';
import PersonIcon from '@material-ui/icons/Person';
import ConfigContext from 'base-shell/lib/providers/Config/Context';
import MenuContext from '../../providers/Menu/Context';
import ThemeContext from '../../providers/Theme/Context';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import clsx from 'clsx';
import ArroWDropDownIcon from '@material-ui/icons/ArrowDropDown';
import ArroWDropUpIcon from '@material-ui/icons/ArrowDropUp';
import Brightness4Icon from '@material-ui/icons/Brightness4';
import BrightnessHighIcon from '@material-ui/icons/BrightnessHigh';
var useStyles = makeStyles(function (theme) {
  return {
    paper: {
      backgroundColor: theme.palette.primary.dark,
      margin: 0,
      padding: 0
    },
    listItem: {
      color: theme.palette.primary.contrastText,
      cursor: 'pointer'
    },
    icon: {
      color: theme.palette.primary.contrastText,
      cursor: 'pointer'
    },
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: theme.spacing(0, 2)
    }, theme.mixins.toolbar)
  };
});

var MenuHeader = function MenuHeader() {
  var theme = useTheme();

  var _useContext = useContext(ConfigContext),
      appConfig = _useContext.appConfig;

  var _useContext2 = useContext(ThemeContext),
      type = _useContext2.type,
      setType = _useContext2.setType;

  var _ref = appConfig || {},
      menu = _ref.menu;

  var authData = appConfig.auth.getData();
  var classes = useStyles();

  var _useContext3 = useContext(MenuContext),
      isDesktop = _useContext3.isDesktop,
      isDesktopOpen = _useContext3.isDesktopOpen,
      setDesktopOpen = _useContext3.setDesktopOpen,
      isMini = _useContext3.isMini,
      setMini = _useContext3.setMini,
      isAuthMenuOpen = _useContext3.isAuthMenuOpen,
      setAuthMenuOpen = _useContext3.setAuthMenuOpen,
      useMiniMode = _useContext3.useMiniMode;

  return /*#__PURE__*/React.createElement(Paper, {
    square: true,
    className: classes.paper
  }, isMini && authData.isAuthorised && /*#__PURE__*/React.createElement("div", {
    className: classes.toolbar
  }), /*#__PURE__*/React.createElement(List, {
    className: clsx(!authData.isAuthorised && classes.toolbar)
  }, /*#__PURE__*/React.createElement(ListItem, {
    className: classes.listItem
  }, authData.isAuthorised && /*#__PURE__*/React.createElement(React.Fragment, null, authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(Avatar, {
    src: authData.photoURL,
    alt: "user"
  })), !authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(Avatar, null, authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)))), !isMini && /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      setType(type === 'light' ? 'dark' : 'light');
    }
  }, type === 'light' && /*#__PURE__*/React.createElement(Brightness4Icon, {
    classes: {
      root: classes.icon
    }
  }), type === 'dark' && /*#__PURE__*/React.createElement(BrightnessHighIcon, {
    classes: {
      root: classes.icon
    }
  })), isDesktop && /*#__PURE__*/React.createElement(React.Fragment, null, useMiniMode && /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      setMini(true);
      setDesktopOpen(false);
    }
  }, /*#__PURE__*/React.createElement(ChromeReaderMode, {
    classes: {
      root: classes.icon
    }
  })), /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    onClick: function onClick() {
      setDesktopOpen(false);
    }
  }, theme.direction === 'rtl' && /*#__PURE__*/React.createElement(ChevronRight, {
    classes: {
      root: classes.icon
    }
  }), theme.direction !== 'rtl' && /*#__PURE__*/React.createElement(ChevronLeft, {
    classes: {
      root: classes.icon
    }
  })), "  "))), authData.isAuthorised && /*#__PURE__*/React.createElement(ListItem, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, !isDesktopOpen && isDesktop && authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, null, /*#__PURE__*/React.createElement(Avatar, {
    src: authData.photoURL,
    alt: "person",
    style: {
      marginLeft: -7,
      marginTop: 3
    }
  })), !isMini && /*#__PURE__*/React.createElement(ListItemText, {
    classes: {
      primary: classes.listItem,
      secondary: classes.listItem
    },
    style: {
      marginLeft: !isDesktopOpen && isDesktop && authData.photoURL ? 7 : undefined
    },
    primary: authData.displayName,
    secondary: authData.email
  }), isDesktopOpen && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(IconButton, null, isAuthMenuOpen && /*#__PURE__*/React.createElement(ArroWDropUpIcon, {
    classes: {
      root: classes.icon
    }
  }), !isAuthMenuOpen && /*#__PURE__*/React.createElement(ArroWDropDownIcon, {
    classes: {
      root: classes.icon
    }
  }))))));
};

export default MenuHeader;

==> material-ui-shell-1.0.10.tgz: package/es/components/MenuHeader/MenuHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext } from 'react';
import Avatar from '@material-ui/core/Avatar';
import ChevronLeft from '@material-ui/icons/ChevronLeft';
import ChevronRight from '@material-ui/icons/ChevronRight';
import ChromeReaderMode from '@material-ui/icons/ChromeReaderMode';
import IconButton from '@material-ui/core/IconButton';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemAvatar from '@material-ui/core/ListItemAvatar';
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
import ListItemText from '@material-ui/core/ListItemText';
import Paper from '@material-ui/core/Paper';
import PersonIcon from '@material-ui/icons/Person';
import ConfigContext from 'base-shell/lib/providers/Config/Context';
import MenuContext from 'material-ui-shell/lib/providers/Menu/Context';
import ThemeContext from 'material-ui-shell/lib/providers/Theme/Context';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import clsx from 'clsx';
import ArroWDropDownIcon from '@material-ui/icons/ArrowDropDown';
import ArroWDropUpIcon from '@material-ui/icons/ArrowDropUp';
import Brightness4Icon from '@material-ui/icons/Brightness4';
import BrightnessHighIcon from '@material-ui/icons/BrightnessHigh';
var useStyles = makeStyles(function (theme) {
  return {
    paper: {
      backgroundColor: theme.palette.primary.dark,
      margin: 0,
      padding: 0
    },
    listItem: {
      color: theme.palette.primary.contrastText,
      cursor: 'pointer'
    },
    icon: {
      color: theme.palette.primary.contrastText,
      cursor: 'pointer'
    },
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: theme.spacing(0, 2)
    }, theme.mixins.toolbar)
  };
});

var MenuHeader = function MenuHeader() {
  var theme = useTheme();

  var _useContext = useContext(ConfigContext),
      appConfig = _useContext.appConfig;

  var _useContext2 = useContext(ThemeContext),
      type = _useContext2.type,
      setType = _useContext2.setType;

  var _ref = appConfig || {},
      menu = _ref.menu;

  var authData = appConfig.auth.getData();
  var classes = useStyles();

  var _useContext3 = useContext(MenuContext),
      isDesktop = _useContext3.isDesktop,
      isDesktopOpen = _useContext3.isDesktopOpen,
      setDesktopOpen = _useContext3.setDesktopOpen,
      isMini = _useContext3.isMini,
      setMini = _useContext3.setMini,
      isAuthMenuOpen = _useContext3.isAuthMenuOpen,
      setAuthMenuOpen = _useContext3.setAuthMenuOpen,
      useMiniMode = _useContext3.useMiniMode;

  return /*#__PURE__*/React.createElement(Paper, {
    square: true,
    className: classes.paper
  }, isMini && authData.isAuthorised && /*#__PURE__*/React.createElement("div", {
    className: classes.toolbar
  }), /*#__PURE__*/React.createElement(List, {
    className: clsx(!authData.isAuthorised && classes.toolbar)
  }, /*#__PURE__*/React.createElement(ListItem, {
    className: classes.listItem
  }, authData.isAuthorised && /*#__PURE__*/React.createElement(React.Fragment, null, authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(Avatar, {
    src: authData.photoURL,
    alt: "user"
  })), !authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(Avatar, null, authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)))), !isMini && /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      setType(type === 'light' ? 'dark' : 'light');
    }
  }, type === 'light' && /*#__PURE__*/React.createElement(Brightness4Icon, {
    classes: {
      root: classes.icon
    }
  }), type === 'dark' && /*#__PURE__*/React.createElement(BrightnessHighIcon, {
    classes: {
      root: classes.icon
    }
  })), isDesktop && /*#__PURE__*/React.createElement(React.Fragment, null, useMiniMode && /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      setMini(true);
      setDesktopOpen(false);
    }
  }, /*#__PURE__*/React.createElement(ChromeReaderMode, {
    classes: {
      root: classes.icon
    }
  })), /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    onClick: function onClick() {
      setDesktopOpen(false);
    }
  }, theme.direction === 'rtl' && /*#__PURE__*/React.createElement(ChevronRight, {
    classes: {
      root: classes.icon
    }
  }), theme.direction !== 'rtl' && /*#__PURE__*/React.createElement(ChevronLeft, {
    classes: {
      root: classes.icon
    }
  })), ' '))), authData.isAuthorised && /*#__PURE__*/React.createElement(ListItem, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, !isDesktopOpen && isDesktop && authData.photoURL && /*#__PURE__*/React.createElement(ListItemAvatar, null, /*#__PURE__*/React.createElement(Avatar, {
    src: authData.photoURL,
    alt: "person",
    style: {
      marginLeft: -7,
      marginTop: 3
    }
  })), !isMini && /*#__PURE__*/React.createElement(ListItemText, {
    classes: {
      primary: classes.listItem,
      secondary: classes.listItem
    },
    style: {
      marginLeft: !isDesktopOpen && isDesktop && authData.photoURL ? 7 : undefined
    },
    primary: authData.displayName,
    secondary: authData.email
  }), isDesktopOpen && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
    onClick: function onClick() {
      setAuthMenuOpen(!isAuthMenuOpen);
    }
  }, /*#__PURE__*/React.createElement(IconButton, null, isAuthMenuOpen && /*#__PURE__*/React.createElement(ArroWDropUpIcon, {
    classes: {
      root: classes.icon
    }
  }), !isAuthMenuOpen && /*#__PURE__*/React.createElement(ArroWDropDownIcon, {
    classes: {
      root: classes.icon
    }
  }))))));
};

export default MenuHeader;
